# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class DomainRecord(pulumi.CustomResource):
    domain_id: pulumi.Output[float]
    """
    The ID of the Domain to access.  *Changing `domain_id` forces the creation of a new Linode Domain Record.*.
    """
    name: pulumi.Output[str]
    """
    The name of this Record. Required for non-`SRV` records. Setting this is invalid for `SRV` records as it is generated by the API. This field's actual usage depends on the type of record this represents. For A and AAAA records, this is the subdomain being associated with an IP address.
    """
    port: pulumi.Output[float]
    """
    The port this Record points to.
    """
    priority: pulumi.Output[float]
    """
    The priority of the target host. Lower values are preferred.
    """
    protocol: pulumi.Output[str]
    """
    The protocol this Record's service communicates with. Only valid for SRV records.
    """
    record_type: pulumi.Output[str]
    """
    The type of Record this is in the DNS system. For example, A records associate a domain name with an IPv4 address, and AAAA records associate a domain name with an IPv6 address. *Changing `record_type` forces the creation of a new Linode Domain Record.*.
    """
    service: pulumi.Output[str]
    """
    The service this Record identified. Only valid for SRV records.
    """
    tag: pulumi.Output[str]
    """
    The tag portion of a CAA record. It is invalid to set this on other record types.
    """
    target: pulumi.Output[str]
    """
    The target for this Record. This field's actual usage depends on the type of record this represents. For A and AAAA records, this is the address the named Domain should resolve to.
    - - -
    """
    ttl_sec: pulumi.Output[float]
    """
    'Time to Live' - the amount of time in seconds that this Domain's records may be cached by resolvers or other domain servers. Valid values are 300, 3600, 7200, 14400, 28800, 57600, 86400, 172800, 345600, 604800, 1209600, and 2419200 - any other value will be rounded to the nearest valid value.
    """
    weight: pulumi.Output[float]
    """
    The relative weight of this Record. Higher values are preferred.
    """
    def __init__(__self__, resource_name, opts=None, domain_id=None, name=None, port=None, priority=None, protocol=None, record_type=None, service=None, tag=None, target=None, ttl_sec=None, weight=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Linode Domain Record resource.  This can be used to create, modify, and delete Linodes Domain Records.
        For more information, see [DNS Manager](https://www.linode.com/docs/platform/manager/dns-manager/) and the [Linode APIv4 docs](https://developers.linode.com/api/v4#operation/createDomainRecord).


        ## Attributes

        This resource exports no additional attributes.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-linode/blob/master/website/docs/r/domain_record.html.md.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] domain_id: The ID of the Domain to access.  *Changing `domain_id` forces the creation of a new Linode Domain Record.*.
        :param pulumi.Input[str] name: The name of this Record. Required for non-`SRV` records. Setting this is invalid for `SRV` records as it is generated by the API. This field's actual usage depends on the type of record this represents. For A and AAAA records, this is the subdomain being associated with an IP address.
        :param pulumi.Input[float] port: The port this Record points to.
        :param pulumi.Input[float] priority: The priority of the target host. Lower values are preferred.
        :param pulumi.Input[str] protocol: The protocol this Record's service communicates with. Only valid for SRV records.
        :param pulumi.Input[str] record_type: The type of Record this is in the DNS system. For example, A records associate a domain name with an IPv4 address, and AAAA records associate a domain name with an IPv6 address. *Changing `record_type` forces the creation of a new Linode Domain Record.*.
        :param pulumi.Input[str] service: The service this Record identified. Only valid for SRV records.
        :param pulumi.Input[str] tag: The tag portion of a CAA record. It is invalid to set this on other record types.
        :param pulumi.Input[str] target: The target for this Record. This field's actual usage depends on the type of record this represents. For A and AAAA records, this is the address the named Domain should resolve to.
               - - -
        :param pulumi.Input[float] ttl_sec: 'Time to Live' - the amount of time in seconds that this Domain's records may be cached by resolvers or other domain servers. Valid values are 300, 3600, 7200, 14400, 28800, 57600, 86400, 172800, 345600, 604800, 1209600, and 2419200 - any other value will be rounded to the nearest valid value.
        :param pulumi.Input[float] weight: The relative weight of this Record. Higher values are preferred.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if domain_id is None:
                raise TypeError("Missing required property 'domain_id'")
            __props__['domain_id'] = domain_id
            __props__['name'] = name
            __props__['port'] = port
            __props__['priority'] = priority
            __props__['protocol'] = protocol
            if record_type is None:
                raise TypeError("Missing required property 'record_type'")
            __props__['record_type'] = record_type
            __props__['service'] = service
            __props__['tag'] = tag
            if target is None:
                raise TypeError("Missing required property 'target'")
            __props__['target'] = target
            __props__['ttl_sec'] = ttl_sec
            __props__['weight'] = weight
        super(DomainRecord, __self__).__init__(
            'linode:index/domainRecord:DomainRecord',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, domain_id=None, name=None, port=None, priority=None, protocol=None, record_type=None, service=None, tag=None, target=None, ttl_sec=None, weight=None):
        """
        Get an existing DomainRecord resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] domain_id: The ID of the Domain to access.  *Changing `domain_id` forces the creation of a new Linode Domain Record.*.
        :param pulumi.Input[str] name: The name of this Record. Required for non-`SRV` records. Setting this is invalid for `SRV` records as it is generated by the API. This field's actual usage depends on the type of record this represents. For A and AAAA records, this is the subdomain being associated with an IP address.
        :param pulumi.Input[float] port: The port this Record points to.
        :param pulumi.Input[float] priority: The priority of the target host. Lower values are preferred.
        :param pulumi.Input[str] protocol: The protocol this Record's service communicates with. Only valid for SRV records.
        :param pulumi.Input[str] record_type: The type of Record this is in the DNS system. For example, A records associate a domain name with an IPv4 address, and AAAA records associate a domain name with an IPv6 address. *Changing `record_type` forces the creation of a new Linode Domain Record.*.
        :param pulumi.Input[str] service: The service this Record identified. Only valid for SRV records.
        :param pulumi.Input[str] tag: The tag portion of a CAA record. It is invalid to set this on other record types.
        :param pulumi.Input[str] target: The target for this Record. This field's actual usage depends on the type of record this represents. For A and AAAA records, this is the address the named Domain should resolve to.
               - - -
        :param pulumi.Input[float] ttl_sec: 'Time to Live' - the amount of time in seconds that this Domain's records may be cached by resolvers or other domain servers. Valid values are 300, 3600, 7200, 14400, 28800, 57600, 86400, 172800, 345600, 604800, 1209600, and 2419200 - any other value will be rounded to the nearest valid value.
        :param pulumi.Input[float] weight: The relative weight of this Record. Higher values are preferred.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["domain_id"] = domain_id
        __props__["name"] = name
        __props__["port"] = port
        __props__["priority"] = priority
        __props__["protocol"] = protocol
        __props__["record_type"] = record_type
        __props__["service"] = service
        __props__["tag"] = tag
        __props__["target"] = target
        __props__["ttl_sec"] = ttl_sec
        __props__["weight"] = weight
        return DomainRecord(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

__config__ = pulumi.Config('linode')

api_version = __config__.get('apiVersion') or utilities.get_env('LINODE_API_VERSION')
"""
An HTTP User-Agent Prefix to prepend in API requests.
"""

token = __config__.get('token') or utilities.get_env('LINODE_TOKEN', 'LINODE_API_TOKEN')
"""
The token that allows you access to your Linode account
"""

ua_prefix = __config__.get('uaPrefix') or utilities.get_env('LINODE_UA_PREFIX')
"""
An HTTP User-Agent Prefix to prepend in API requests.
"""

url = __config__.get('url') or utilities.get_env('LINODE_URL')
"""
The HTTP(S) API address of the Linode API to use.
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class StackScript(pulumi.CustomResource):
    created: pulumi.Output[str]
    """
    The date this StackScript was created.
    """
    deployments_active: pulumi.Output[float]
    """
    Count of currently active, deployed Linodes created from this StackScript.
    """
    deployments_total: pulumi.Output[float]
    """
    The total number of times this StackScript has been deployed.
    """
    description: pulumi.Output[str]
    """
    A description for the StackScript.
    """
    images: pulumi.Output[list]
    """
    An array of Image IDs representing the Images that this StackScript is compatible for deploying with.
    """
    is_public: pulumi.Output[bool]
    """
    This determines whether other users can use your StackScript. Once a StackScript is made public, it cannot be made private. *Changing `is_public` forces the creation of a new StackScript*
    """
    label: pulumi.Output[str]
    """
    The StackScript's label is for display purposes only.
    """
    rev_note: pulumi.Output[str]
    """
    This field allows you to add notes for the set of revisions made to this StackScript.
    """
    script: pulumi.Output[str]
    """
    The script to execute when provisioning a new Linode with this StackScript.
    """
    updated: pulumi.Output[str]
    """
    The date this StackScript was updated.
    """
    user_defined_fields: pulumi.Output[list]
    """
    This is a list of fields defined with a special syntax inside this StackScript that allow for supplying customized
    parameters during deployment.

      * `default` (`str`)
      * `example` (`str`)
      * `label` (`str`) - The StackScript's label is for display purposes only.
      * `manyOf` (`str`)
      * `name` (`str`)
      * `oneOf` (`str`)
    """
    user_gravatar_id: pulumi.Output[str]
    """
    The Gravatar ID for the User who created the StackScript.
    """
    username: pulumi.Output[str]
    """
    The User who created the StackScript.
    """
    def __init__(__self__, resource_name, opts=None, description=None, images=None, is_public=None, label=None, rev_note=None, script=None, user_defined_fields=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a StackScript resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: A description for the StackScript.
        :param pulumi.Input[list] images: An array of Image IDs representing the Images that this StackScript is compatible for deploying with.
        :param pulumi.Input[bool] is_public: This determines whether other users can use your StackScript. Once a StackScript is made public, it cannot be made private. *Changing `is_public` forces the creation of a new StackScript*
        :param pulumi.Input[str] label: The StackScript's label is for display purposes only.
        :param pulumi.Input[str] rev_note: This field allows you to add notes for the set of revisions made to this StackScript.
        :param pulumi.Input[str] script: The script to execute when provisioning a new Linode with this StackScript.
        :param pulumi.Input[list] user_defined_fields: This is a list of fields defined with a special syntax inside this StackScript that allow for supplying customized
               parameters during deployment.

        The **user_defined_fields** object supports the following:

          * `default` (`pulumi.Input[str]`)
          * `example` (`pulumi.Input[str]`)
          * `label` (`pulumi.Input[str]`) - The StackScript's label is for display purposes only.
          * `manyOf` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`)
          * `oneOf` (`pulumi.Input[str]`)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if description is None:
                raise TypeError("Missing required property 'description'")
            __props__['description'] = description
            if images is None:
                raise TypeError("Missing required property 'images'")
            __props__['images'] = images
            __props__['is_public'] = is_public
            if label is None:
                raise TypeError("Missing required property 'label'")
            __props__['label'] = label
            __props__['rev_note'] = rev_note
            if script is None:
                raise TypeError("Missing required property 'script'")
            __props__['script'] = script
            __props__['user_defined_fields'] = user_defined_fields
            __props__['created'] = None
            __props__['deployments_active'] = None
            __props__['deployments_total'] = None
            __props__['updated'] = None
            __props__['user_gravatar_id'] = None
            __props__['username'] = None
        super(StackScript, __self__).__init__(
            'linode:index/stackScript:StackScript',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, created=None, deployments_active=None, deployments_total=None, description=None, images=None, is_public=None, label=None, rev_note=None, script=None, updated=None, user_defined_fields=None, user_gravatar_id=None, username=None):
        """
        Get an existing StackScript resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] created: The date this StackScript was created.
        :param pulumi.Input[float] deployments_active: Count of currently active, deployed Linodes created from this StackScript.
        :param pulumi.Input[float] deployments_total: The total number of times this StackScript has been deployed.
        :param pulumi.Input[str] description: A description for the StackScript.
        :param pulumi.Input[list] images: An array of Image IDs representing the Images that this StackScript is compatible for deploying with.
        :param pulumi.Input[bool] is_public: This determines whether other users can use your StackScript. Once a StackScript is made public, it cannot be made private. *Changing `is_public` forces the creation of a new StackScript*
        :param pulumi.Input[str] label: The StackScript's label is for display purposes only.
        :param pulumi.Input[str] rev_note: This field allows you to add notes for the set of revisions made to this StackScript.
        :param pulumi.Input[str] script: The script to execute when provisioning a new Linode with this StackScript.
        :param pulumi.Input[str] updated: The date this StackScript was updated.
        :param pulumi.Input[list] user_defined_fields: This is a list of fields defined with a special syntax inside this StackScript that allow for supplying customized
               parameters during deployment.
        :param pulumi.Input[str] user_gravatar_id: The Gravatar ID for the User who created the StackScript.
        :param pulumi.Input[str] username: The User who created the StackScript.

        The **user_defined_fields** object supports the following:

          * `default` (`pulumi.Input[str]`)
          * `example` (`pulumi.Input[str]`)
          * `label` (`pulumi.Input[str]`) - The StackScript's label is for display purposes only.
          * `manyOf` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`)
          * `oneOf` (`pulumi.Input[str]`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["created"] = created
        __props__["deployments_active"] = deployments_active
        __props__["deployments_total"] = deployments_total
        __props__["description"] = description
        __props__["images"] = images
        __props__["is_public"] = is_public
        __props__["label"] = label
        __props__["rev_note"] = rev_note
        __props__["script"] = script
        __props__["updated"] = updated
        __props__["user_defined_fields"] = user_defined_fields
        __props__["user_gravatar_id"] = user_gravatar_id
        __props__["username"] = username
        return StackScript(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetDomainRecordResult:
    """
    A collection of values returned by getDomainRecord.
    """
    def __init__(__self__, domain_id=None, id=None, name=None, port=None, priority=None, protocol=None, service=None, tag=None, target=None, ttl_sec=None, type=None, weight=None):
        if domain_id and not isinstance(domain_id, float):
            raise TypeError("Expected argument 'domain_id' to be a float")
        __self__.domain_id = domain_id
        if id and not isinstance(id, float):
            raise TypeError("Expected argument 'id' to be a float")
        __self__.id = id
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if port and not isinstance(port, float):
            raise TypeError("Expected argument 'port' to be a float")
        __self__.port = port
        if priority and not isinstance(priority, float):
            raise TypeError("Expected argument 'priority' to be a float")
        __self__.priority = priority
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        __self__.protocol = protocol
        if service and not isinstance(service, str):
            raise TypeError("Expected argument 'service' to be a str")
        __self__.service = service
        if tag and not isinstance(tag, str):
            raise TypeError("Expected argument 'tag' to be a str")
        __self__.tag = tag
        if target and not isinstance(target, str):
            raise TypeError("Expected argument 'target' to be a str")
        __self__.target = target
        if ttl_sec and not isinstance(ttl_sec, float):
            raise TypeError("Expected argument 'ttl_sec' to be a float")
        __self__.ttl_sec = ttl_sec
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        __self__.type = type
        if weight and not isinstance(weight, float):
            raise TypeError("Expected argument 'weight' to be a float")
        __self__.weight = weight
class AwaitableGetDomainRecordResult(GetDomainRecordResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainRecordResult(
            domain_id=self.domain_id,
            id=self.id,
            name=self.name,
            port=self.port,
            priority=self.priority,
            protocol=self.protocol,
            service=self.service,
            tag=self.tag,
            target=self.target,
            ttl_sec=self.ttl_sec,
            type=self.type,
            weight=self.weight)

def get_domain_record(domain_id=None,id=None,name=None,opts=None):
    """
    Provides information about a Linode Domain Record.


    ## Attributes

    The Linode Volume resource exports the following attributes:

    - `id` - The unique ID of the Domain Record.

    - `name` - The name of the Record.

    - `domain_id` - The associated domain's unique ID.

    - `type` - The type of Record this is in the DNS system.

    - `ttl_sec` - The amount of time in seconds that this Domain's records may be cached by resolvers or other domain servers.

    - `target` - The target for this Record. This field's actual usage depends on the type of record this represents. For A and AAAA records, this is the address the named Domain should resolve to.

    - `priority` - The priority of the target host. Lower values are preferred.

    - `weight` - The relative weight of this Record. Higher values are preferred.

    - `port` - The port this Record points to.

    - `protocol` - The protocol this Record's service communicates with. Only valid for SRV records.

    - `service` - The service this Record identified. Only valid for SRV records.

    - `tag` - The tag portion of a CAA record.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-linode/blob/master/website/docs/d/domain_record.html.md.
    """
    __args__ = dict()


    __args__['domainId'] = domain_id
    __args__['id'] = id
    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('linode:index/getDomainRecord:getDomainRecord', __args__, opts=opts).value

    return AwaitableGetDomainRecordResult(
        domain_id=__ret__.get('domainId'),
        id=__ret__.get('id'),
        name=__ret__.get('name'),
        port=__ret__.get('port'),
        priority=__ret__.get('priority'),
        protocol=__ret__.get('protocol'),
        service=__ret__.get('service'),
        tag=__ret__.get('tag'),
        target=__ret__.get('target'),
        ttl_sec=__ret__.get('ttlSec'),
        type=__ret__.get('type'),
        weight=__ret__.get('weight'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import importlib
# Make subpackages available:
__all__ = ['config']
for pkg in __all__:
    if pkg != 'config':
        importlib.import_module(f'{__name__}.{pkg}')

# Export this package's modules as members:
from .domain import *
from .domain_record import *
from .get_account import *
from .get_domain import *
from .get_domain_record import *
from .get_image import *
from .get_instance_type import *
from .get_networking_ip import *
from .get_object_storage_cluster import *
from .get_profile import *
from .get_region import *
from .get_ssh_key import *
from .get_stack_script import *
from .get_user import *
from .get_volume import *
from .image import *
from .instance import *
from .node_balancer import *
from .node_balancer_config import *
from .node_balancer_node import *
from .object_storage_bucket import *
from .object_storage_key import *
from .provider import *
from .rdns import *
from .ssh_key import *
from .stack_script import *
from .token import *
from .volume import *



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetAccountResult:
    """
    A collection of values returned by getAccount.
    """
    def __init__(__self__, address1=None, address2=None, balance=None, city=None, company=None, country=None, email=None, first_name=None, id=None, last_name=None, phone=None, state=None, zip=None):
        if address1 and not isinstance(address1, str):
            raise TypeError("Expected argument 'address1' to be a str")
        __self__.address1 = address1
        if address2 and not isinstance(address2, str):
            raise TypeError("Expected argument 'address2' to be a str")
        __self__.address2 = address2
        if balance and not isinstance(balance, float):
            raise TypeError("Expected argument 'balance' to be a float")
        __self__.balance = balance
        if city and not isinstance(city, str):
            raise TypeError("Expected argument 'city' to be a str")
        __self__.city = city
        if company and not isinstance(company, str):
            raise TypeError("Expected argument 'company' to be a str")
        __self__.company = company
        if country and not isinstance(country, str):
            raise TypeError("Expected argument 'country' to be a str")
        __self__.country = country
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        __self__.email = email
        if first_name and not isinstance(first_name, str):
            raise TypeError("Expected argument 'first_name' to be a str")
        __self__.first_name = first_name
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
        if last_name and not isinstance(last_name, str):
            raise TypeError("Expected argument 'last_name' to be a str")
        __self__.last_name = last_name
        if phone and not isinstance(phone, str):
            raise TypeError("Expected argument 'phone' to be a str")
        __self__.phone = phone
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        __self__.state = state
        if zip and not isinstance(zip, str):
            raise TypeError("Expected argument 'zip' to be a str")
        __self__.zip = zip
class AwaitableGetAccountResult(GetAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountResult(
            address1=self.address1,
            address2=self.address2,
            balance=self.balance,
            city=self.city,
            company=self.company,
            country=self.country,
            email=self.email,
            first_name=self.first_name,
            id=self.id,
            last_name=self.last_name,
            phone=self.phone,
            state=self.state,
            zip=self.zip)

def get_account(opts=None):
    """
    Provides information about a Linode account.

    This data source should not be used in conjuction with the `LINODE_DEBUG` option.  See the [debugging notes](https://www.terraform.io/docs/providers/linode/index.html#debugging) for more details.


    ## Attributes

    The Linode Account resource exports the following attributes:

    * `email` - The email address for this Account, for account management communications, and may be used for other communications as configured.

    * `first_name` - The first name of the person associated with this Account.

    * `last_name` - The last name of the person associated with this Account.

    * `company` - The company name associated with this Account.

    * `address_1` - First line of this Account's billing address.

    * `address_2` - Second line of this Account's billing address.

    * `phone` - The phone number associated with this Account.

    * `city` - The city for this Account's billing address.

    * `state` - If billing address is in the United States, this is the State portion of the Account's billing address. If the address is outside the US, this is the Province associated with the Account's billing address.

    * `country` - The two-letter country code of this Account's billing address.

    * `zip` - The zip code of this Account's billing address.

    * `balance` - This Account's balance, in US dollars.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-linode/blob/master/website/docs/d/account.html.md.
    """
    __args__ = dict()


    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('linode:index/getAccount:getAccount', __args__, opts=opts).value

    return AwaitableGetAccountResult(
        address1=__ret__.get('address1'),
        address2=__ret__.get('address2'),
        balance=__ret__.get('balance'),
        city=__ret__.get('city'),
        company=__ret__.get('company'),
        country=__ret__.get('country'),
        email=__ret__.get('email'),
        first_name=__ret__.get('firstName'),
        id=__ret__.get('id'),
        last_name=__ret__.get('lastName'),
        phone=__ret__.get('phone'),
        state=__ret__.get('state'),
        zip=__ret__.get('zip'))
